# -*- encoding: utf-8 -*-

import locale

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from .helpers import (
    get_compose_path, get_rpms_json_path, get_modules_json_path)

from compose_utils import diff


EXPECTED_DIFF = {
    "Client": {
        "added": [
            "dummy-elinks-debuginfo.i386",
            "dummy-elinks-debuginfo.x86_64",
            "dummy-elinks.i386",
            "dummy-elinks.src",
            "dummy-elinks.x86_64",
        ],
        "dropped": [
            "dummy-tftp-debuginfo.i386",
            "dummy-tftp-debuginfo.x86_64",
            "dummy-tftp.i386",
            "dummy-tftp.src",
            "dummy-tftp.x86_64",
        ],
    },
    "Server": {
        "added": [
            "dummy-elinks-debuginfo.s390x",
            "dummy-elinks-debuginfo.x86_64",
            "dummy-elinks.s390x",
            "dummy-elinks.src",
            "dummy-elinks.x86_64",
        ],
        "dropped": [
            "dummy-tftp-debuginfo.s390x",
            "dummy-tftp-debuginfo.x86_64",
            "dummy-tftp.s390x",
            "dummy-tftp.src",
            "dummy-tftp.x86_64",
        ],
    },
}


EXPECTED_DIFF_MODULAR = {
    "Temporary": {
        "added": [
            "xorg-x11-font-foobar.flatpak-common:f30.x86_64",
            "xorg-x11-font-only-in-new.flatpak-common:f30.x86_64"
        ],
        "dropped": [
            "xorg-x11-font-only-in-old.flatpak-common:f30.x86_64",
            "xorg-x11-font-only-in-old.x86_64"
        ]
    }
}


class DiffRpmsTest(unittest.TestCase):
    def setUp(self):
        locale.setlocale(locale.LC_TIME, "C")

    def test_diff(self):
        old_compose = get_compose_path("DP-1.0-20160315.t.0")
        new_compose = get_compose_path("DP-1.0-20160315.t.1")
        cdiff = diff.ComposeRpmsDiff()

        data = cdiff.get_diff(old_compose, new_compose)
        self.maxDiff = None
        self.assertEqual(data["diff"], EXPECTED_DIFF)

    def test_diff_with_rpms_json_file(self):
        rpms_file_path = get_rpms_json_path("DP-1.0-20160315.t.0")
        new_compose = get_compose_path("DP-1.0-20160315.t.1")
        cdiff = diff.ComposeRpmsDiff()

        data = cdiff.get_diff_rpms_file(rpms_file_path, new_compose)
        self.maxDiff = None
        self.assertEqual(data["diff"], EXPECTED_DIFF)

    def test_diff_modules(self):
        old_compose = get_compose_path("odcs-369-1-20190604.n.0")
        new_compose = get_compose_path("odcs-370-1-20190604.n.0")
        cdiff = diff.ComposeRpmsDiff()

        data = cdiff.get_diff(old_compose, new_compose)
        self.maxDiff = None
        self.assertEqual(data["diff"], EXPECTED_DIFF_MODULAR)

    def test_diff_with_rpms_json_file_modules(self):
        rpms_file_path = get_rpms_json_path("odcs-369-1-20190604.n.0")
        modules_file_path = get_modules_json_path("odcs-369-1-20190604.n.0")
        new_compose = get_compose_path("odcs-370-1-20190604.n.0")
        cdiff = diff.ComposeRpmsDiff()

        data = cdiff.get_diff_rpms_file(
            rpms_file_path, new_compose, modules_file_path)
        self.maxDiff = None
        self.assertEqual(data["diff"], EXPECTED_DIFF_MODULAR)
