# -*- encoding: utf-8 -*-

from textwrap import dedent

try:
    import unittest2 as unittest
except ImportError:
    import unittest

import mock
from six import StringIO

from .helpers import get_compose, get_compose_path

from compose_utils import essentials


class GetPackageVersionTest(unittest.TestCase):
    def test_no_match(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        self.assertIsNone(essentials.get_package_version(compose, "kernel"))

    def test_with_kernel(self):
        compose = get_compose("DP-1.0-20181012.t.0")
        self.assertEqual(
            essentials.get_package_version(compose, "kernel"),
            "Kernel: kernel-1.0-1",
        )


class GetContainersTest(unittest.TestCase):
    def test_no_metadata(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        self.assertIsNone(essentials.get_containers(compose))

    def test_with_containers(self):
        compose = get_compose("DP-1.0-20181012.t.0")
        self.maxDiff = None
        self.assertEqual(
            essentials.get_containers(compose),
            dedent(
                """\
                Containers:
                 * dp-1.0-1 (base)
                   - registry.example.com/dp:latest-aarch64
                   - registry.example.com/dp:latest-x86_64"""
            ),
        )


class GetImagesTest(unittest.TestCase):
    def test_no_metadata(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        self.assertIsNone(essentials.get_images(compose))

    def test_with_images(self):
        compose = get_compose("DP-1.0-20181012.t.0")
        self.assertEqual(
            essentials.get_images(compose),
            dedent(
                """\
                Images:
                 * DP-1.0-20181012.t.0-Client-i386.qcow2
                 * DP-1.0-20181012.t.0-Server-x86_64.qcow2"""
            ),
        )


class GetEssentialsTest(unittest.TestCase):
    def test_no_metadata(self):
        compose_path = get_compose_path("DP-1.0-20160315.t.0")
        self.assertEqual(essentials.get_essentials(compose_path), [])

    def test_with_metadata(self):
        compose_path = get_compose_path("DP-1.0-20181012.t.0")
        self.assertEqual(len(essentials.get_essentials(compose_path)), 3)


class PrintDetailsTest(unittest.TestCase):
    def test_printing(self):
        with mock.patch("sys.stdout", new_callable=StringIO) as out:
            essentials.print_details(["foo", "bar"])
        self.assertEqual(out.getvalue(), "foo\nbar\n")
